.. _quick-search:

============
Quick Search
============

The search field found on every page can be used to quickly locate
review requests, users, and groups without needing to do a full search.

As you type, a list of matches will appear. Clicking on a match will
immediately take you to the appropriate page.

If your server has :ref:`full-text search <full-text-search>` enabled, hitting
enter after typing your search terms will perform a full search.

The following can be searched using Quick Search:

* Review request IDs
* Review request summaries
* Usernames
* Users' first/last names
* Group names
* Group display names
